
from zope.schema import TextLine
from zope.interface import Interface
from zope.contentprovider.interfaces import IContentProvider

from collective.searchtool import MessageFactory as _


class ISearchProvider(IContentProvider):
    """ Marker interface that marks browser pages or
        other content provider that promisess searchform
        functionalities """

class ISearchResultItem(Interface):
    """ Marker instance that marks classes that are used 
        to render individual result item"""


class ISimpleSearchForm(Interface):
    """ simple search form (/@@search) """

    search_term = TextLine(
        title       = _(u'Search term'),)
        #description = _(
        #    u'Automatic "and" queries, eg: "car citroen". Search will returns'
        #    u'pages that include all of your search terms.'))






from zope.interface import implements
from zope.component import getMultiAdapter

from z3c.form.form import Form
from z3c.form.field import Fields
from z3c.form.button import buttonAndHandler
from z3c.form.interfaces import IFormLayer
from plone.z3cform import z2
from plone.memoize.instance import memoize

from Acquisition import aq_inner
from Products.CMFCore.utils import getToolByName
from Products.Five.browser import BrowserView
from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
from Products.AdvancedQuery import MatchRegexp, Or, And

from collective.searchtool import MessageFactory as _
from collective.searchtool.interfaces import ISearchResultItem
from collective.searchtool.interfaces import ISearchProvider
from collective.searchtool.interfaces import ISimpleSearchForm


class SimpleSearchResult(BrowserView):
    __call__ = render = ViewPageTemplateFile('simple_results.pt')

    def __init__(self, context, request, view=None):
        self.context = aq_inner(context)
        self.request = request
        self.__parent__ = view

        self.syndication = getToolByName(self.context, 'portal_syndication')
        self.portal_state = getMultiAdapter((self.context, self.request), name=u'plone_portal_state')
        self.site_url = self.portal_state.portal_url()
    
    def render_item(self, item):
        return getMultiAdapter((self.__parent__, item), ISearchResultItem).render()


class SimpleSearchForm(Form):
    label = _('Simple search')
    ignoreContext = True
    fields = Fields(ISimpleSearchForm)
    result_data = []

    @buttonAndHandler(_(u'Search'))
    def search(self, action):
        data, errors = self.extractData()
        if errors: return False
        if not data['search_term']: return True 
        catalog = getToolByName(self.context, 'portal_catalog')
        self.result_data = catalog.evalAdvancedQuery(
            MatchRegexp('SearchableText', '*' + data['search_term'] + '*' ))
        return True


class SimpleSearch(BrowserView):
    implements(ISearchProvider)
     
    form = SimpleSearchForm
    results = SimpleSearchResult
    
    def __init__(self, context, request, view=None):
        self.context = aq_inner(context)
        self.request = request
        self.__parent__ = view

        self.portal_state = getMultiAdapter((self.context, self.request), name=u'plone_portal_state')
        self.site_url = self.portal_state.portal_url()

    def __call__(self):
        return self.render()

    def render(self):
        z2.switch_on(self, request_layer=IFormLayer)
        form = self.form(self.context.aq_inner, self.request)
        results = self.results(self.context.aq_inner, self.request, self)
        html = form()
        results.result_data = form.result_data
        return '<div class="searchPage">'+html+'</div>' + \
               '<div class="seachResultPage">'+results.__of__(self.context)()+'</div>'

    @property
    def label(self):
        return self.form.label

    def update(self):
        pass

    def getPhysicalPath(self):
        """ needed so its possible to do path search over catalog 
              ExtendedPathIndex needs it ... maybe a bug  """
        return self.context.getPhysicalPath()


class SimpleSearchView(BrowserView):
    """ Simple search form page """
    __call__ = ViewPageTemplateFile('simple_browserview.pt')






from zope.interface import implements
from zope.component import getMultiAdapter

from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
from Products.CMFCore.utils import getToolByName

from interfaces import ISearchResultItem


class ResultItem(object):

    implements(ISearchResultItem)

    def __init__(self, provider, brain):
        self.provider = provider
        self.brain = brain

    def render(self):
        try:
            return getMultiAdapter(
                        (self.provider, self.brain),
                        ISearchResultItem,
                        self.brain.Type).render()
        except:
            utils = getToolByName(self.provider.context, 'plone_utils')
            properties = getToolByName(self.provider.context, 'portal_properties')
            return (ViewPageTemplateFile('result.pt').__of__(self.provider))(
                        site_properties = properties['site_properties'],
                        brain = self.brain,
                        utils = utils, )





from zope.interface import Interface
from zope.interface import implements
from zope.component import adapts
from zope.component import getMultiAdapter

from zope.traversing.interfaces import ITraversable
from zope.publisher.interfaces.http import IHTTPRequest

from Acquisition import aq_inner
from Products.Five.traversable import  FiveTraversable

from interfaces import ISearchProvider


class SearchHandler(object):

    implements(ITraversable)
    adapts(Interface, IHTTPRequest)

    def __init__(self, context, request):
        self.context = aq_inner(context)
        self.request = request

    def traverse(self, name, ignored):
        return getMultiAdapter((self.context, self.request, None),
                    ISearchProvider, name)




from setuptools import setup, find_packages
import os

version = '0.1'

setup(name='collective.searchtool',
      version=version,
      description="",
      long_description=open(os.path.join('src', 'collective', 'searchtool', 'README.txt')).read(),
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Framework :: Plone",
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
        ],
      keywords='zope plone search',
      author='Rok Garbas',
      author_email='rok@garbas.si',
      url='https://svn.plone.org/svn/collective/collective.searchtool',
      license='GPL',
      packages = find_packages('src', exclude=['ez_setup']),
      package_dir = {'':'src'},
      namespace_packages=['collective'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          # -*- Extra requirements: -*-
          'plone.z3cform',
      ],
      entry_points="""
      # -*- Entry points: -*-
      """,
      )
